<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ca">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="37"/>
        <location filename="../asciifile/asciifile.cpp" line="43"/>
        <source>Read ascii points</source>
        <translatorcomment>Nota pels traductors: Si un cop enregistrats encara no podeu traduïr i només podeu penjar suggeriments, si us plau demaneu en el forum que us activin els permisos per traduir.
http://forum.librecad.org/LibreCAD-dev-f4361976.html</translatorcomment>
        <translation>Llegeix els punts en ASCII</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>Importa un fitxer de ratllat ESRI</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>Alinea</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>primer punt d&apos;origen:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>primer punt de destí:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>segon punt d&apos;origen:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>segon punt de destí:</translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>Llista les entitats</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation>n</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>Entitat inexistent</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="73"/>
        <source>Layer</source>
        <translation>Capa</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="75"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="76"/>
        <source>Line type</source>
        <translation>Tipus de línia</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Line thickness</source>
        <translation>Gruix de línia</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="78"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="84"/>
        <source>POINT</source>
        <translation>PUNT</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="85"/>
        <location filename="../list/list.cpp" line="195"/>
        <source>in point</source>
        <translation>en el punt</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="90"/>
        <source>LINE</source>
        <translation>LÍNIA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="95"/>
        <source>from point</source>
        <translation>del punt</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="98"/>
        <source>to point</source>
        <translation>al punt</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="103"/>
        <location filename="../list/list.cpp" line="127"/>
        <source>length</source>
        <translation>longitud</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="108"/>
        <source>Angle in XY plane</source>
        <translation>Angle en el plànol XY</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="109"/>
        <source>Inc.</source>
        <translation>Inc.</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="114"/>
        <source>ARC</source>
        <translation>ARC</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="115"/>
        <location filename="../list/list.cpp" line="131"/>
        <location filename="../list/list.cpp" line="141"/>
        <source>center point</source>
        <translation>centre</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="121"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="199"/>
        <source>radius</source>
        <translation>radi</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="122"/>
        <source>initial angle</source>
        <translation>angle inicial</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="123"/>
        <source>final angle</source>
        <translation>angle final</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="130"/>
        <source>CIRCLE</source>
        <translation>CERCLE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="136"/>
        <source>circumference</source>
        <translation>circumferència</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="137"/>
        <source>area</source>
        <translation>àrea</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>ELLIPSE</source>
        <translation type="unfinished">El·lipse</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>major axis</source>
        <translation>eix major</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="162"/>
        <source>CONSTRUCTIONLINE</source>
        <translation type="unfinished">Línia de construcció</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="165"/>
        <source>OVERLAYBOX</source>
        <translation>Quadre sobreposat</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="168"/>
        <source>SOLID</source>
        <translation>SÒLID</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>MTEXT</source>
        <translation>TEXTM</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="175"/>
        <source>TEXT</source>
        <translation>TEXT</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="178"/>
        <source>INSERT</source>
        <translation>INSEREIX</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="181"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>Insertion point</source>
        <translation>Punt d&apos;inserció</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>POLYLINE</source>
        <translation type="unfinished">Polilínia</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="188"/>
        <source>Closed</source>
        <translation>Tancada</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Vertices</source>
        <translation>Vèrtex</translation>
    </message>
    <message>
        <source>curvature</source>
        <translation type="obsolete">Curvatura</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="204"/>
        <source>IMAGE</source>
        <translation>IMATGE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="207"/>
        <source>SPLINE</source>
        <translation>SPLINE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>SPLINEPOINTS</source>
        <translation>PUNTS SPLINE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>HATCH</source>
        <translation>RATLLAT</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="216"/>
        <source>DIMLEADER</source>
        <translation>Cota guia</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="219"/>
        <source>DIMALIGNED</source>
        <translation>Cota alineada</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="222"/>
        <source>DIMLINEAR</source>
        <translation>Cota lineal</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="225"/>
        <source>DIMRADIAL</source>
        <translation>Cota radial</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="228"/>
        <source>DIMDIAMETRIC</source>
        <translation>Cota diametral</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="231"/>
        <source>DIMANGULAR</source>
        <translation>Cota angular</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="234"/>
        <source>UNKNOWN</source>
        <translation>DESCONEGUT</translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>Mateixes propietats</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>seleccioneu l&apos;entitat original:</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>seleccioneu les entitats a canviar</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>Connector de mostra</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="38"/>
        <source>Read PIC file</source>
        <translation>Llegeix un fitxer PIC</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="44"/>
        <source>import PIC file</source>
        <translation>importa un fitxer PIC</translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>Read ascii points</source>
        <translation>Llegeix els punts en ASCII</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="241"/>
        <source>File...</source>
        <translation>Fitxer...</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="248"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space Separator</source>
        <translation>Separació amb espais</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Tab Separator</source>
        <translation>Separació amb tabuladors</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Comma Separator</source>
        <translation>Separació amb comes</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space in Columns</source>
        <translation>Espai en columnes</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>*.odb for Psion 2</source>
        <translation>*.odb per a Psion 2</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="252"/>
        <source>Connect points</source>
        <translation>Uneix els punts</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>2D Point</source>
        <translation>Punt 2D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>Draw 2D Point</source>
        <translation>Traça punt 2D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>3D Point</source>
        <translation>Punt 3D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>Draw 3D Point</source>
        <translation>Traça punt 3D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Point Number</source>
        <translation>Número del punt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Draw point number</source>
        <translation>Traça el número del punt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Point Elevation</source>
        <translation>Alçada del punt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Draw point elevation</source>
        <translation>Traça l&apos;alçada del punt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Point Code</source>
        <translation>Codi del punt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Draw point code</source>
        <translation>Traça el codi del punt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="278"/>
        <source>Accept</source>
        <translation>Accepta</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="283"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="313"/>
        <source>Select file</source>
        <translation>Selecciona el fitxer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point 2D layer is empty</source>
        <translation>La capa del punt 2D és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="323"/>
        <source>Point 3D layer is empty</source>
        <translation>La capa del punt 3D és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point elevation layer is empty</source>
        <translation>La capa de l&apos;alçada del punt és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point elevation height is empty</source>
        <translation>L&apos;alçada del punt és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="328"/>
        <source>Point elevation separation is empty</source>
        <translation>La separació de l&apos;alçada del punt és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point number layer is empty</source>
        <translation>La capa del número del punt és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point number height is empty</source>
        <translation>L&apos;alçada del número del punt és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="333"/>
        <source>Point number separation is empty</source>
        <translation>La separació del número del punt és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="336"/>
        <source>Point code layer is empty</source>
        <translation>La capa del codi del punt és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="337"/>
        <source>Point code height is empty</source>
        <translation>L&apos;alçada del codi del punt és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="338"/>
        <source>Point code separation is empty</source>
        <translation>La separació del codi del punt és buida</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="366"/>
        <source>The file %1 not exist</source>
        <translation>El fitxer %1 no existeix</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="371"/>
        <source>Can&apos;t open the file %1</source>
        <translation>No es pot obrir el fitxer %1</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>Fitxer...</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>Tipus de fitxer:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>Capa</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>Importa un fitxer ESRI</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>Actual</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>Des de les dades:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>Tipus de línia</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>Gruix</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>Punt</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>com a punt</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>com a etiqueta:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>Accepta</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>Seleccioneu fitxer</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translation>Punt i mesura</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation>Punt 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation>Punt múltiple</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation>Punt múltiple i mesura</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation>Punt múltiple 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>Arc</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation>Arc i mesura</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation>Arc 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>Polígon</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation>Polígon i mesura</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation>Polígon 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translation>Multipatch</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>El fitxer %1 no té extensió .shp</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>El fitxer %1 no existeix</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>List entities</source>
        <translation>Llista les entitats</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>Traça una línia</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>X inicial:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>Y inicial:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>X final:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>Y final:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>Accepta</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>Manca X inicial</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>Manca Y inicial</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>Manca X final</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>Manca Y final</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>Connector de mostra</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="67"/>
        <source>File...</source>
        <translation>Fitxer...</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="77"/>
        <source>Scale:</source>
        <translation>Escala:</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="81"/>
        <source>Accept</source>
        <translation>Accepta</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="113"/>
        <source>Select file</source>
        <translation>Selecciona un fitxer</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="121"/>
        <source>Scale Factor is empty or invalid</source>
        <translation>El factor d&apos;escala està buit o no és vàlid</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="134"/>
        <source>The file %1 not exist</source>
        <translation>El fitxer %1 no existeix</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="139"/>
        <source>Can&apos;t open the file %1</source>
        <translation>No es pot obrir el fitxer %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="146"/>
        <source>%1 objects imported</source>
        <translation>%1 objectes importats</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="168"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation>picPunto drawLine: manca el primer punt %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="181"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation>picPunto drawLine: manca el següent punt %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="260"/>
        <location filename="../picfile/picfile.cpp" line="269"/>
        <source>format error in %1</source>
        <translation>error de format en %1</translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation>Connector d&apos;impressió</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="obsolete">Dibuixa</translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation>Imprimeix l&apos;equació</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation>Aquest connector us permet traçar equacions matemàtiques.
Si no voleu utilitzar la forma paramètrica, ometeu l&apos;«Equació 2»
Podeu utilitzar pi quan necessiteu el valor de pi (p. ex. (3*pi)).
Utilitzeu t o x en la vostra equació com a variable o paràmetre.
</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation>Equació 1:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation>Equació 2:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation>valor inicial:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation>valor final:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation>mida del pas:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation>Traça</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation>Segments de línia</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation>Línia poligonal</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation>Punts spline</translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="177"/>
        <source>Layer:</source>
        <translation>Capa:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="210"/>
        <source>Style:</source>
        <translation>Estil:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="211"/>
        <source>Height:</source>
        <translation>Alçada:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="212"/>
        <source>Separation</source>
        <translation>Separació</translation>
    </message>
</context>
</TS>
